<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="id">
<context>
    <name>BatteryWatcherSettings</name>
    <message>
        <location filename="../batterywatchersettings.ui" line="14"/>
        <source>Battery Watcher Settings</source>
        <translation>Pengaturan Pemantau Baterai</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="26"/>
        <source>E&amp;nable Battery Watcher</source>
        <translation>Aktifkan Pemantau Baterai</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="54"/>
        <source>Warning:</source>
        <translation>Peringatan:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="67"/>
        <source> seconds</source>
        <translation> detik</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="77"/>
        <source>Level is low at:</source>
        <translation>Level rendah di:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="90"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="111"/>
        <source>Use icons from theme:</source>
        <translation>Gunakan ikon dari tema:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="125"/>
        <location filename="../batterywatchersettings.cpp" line="93"/>
        <source>Preview</source>
        <translation>Pratayang</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="162"/>
        <source>Charging</source>
        <translation>Mengisi daya</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="200"/>
        <source>Discharging</source>
        <translation>Pengosongan</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="41"/>
        <source>When power is low then:</source>
        <translation>Saat daya rendah maka:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.ui" line="97"/>
        <source>Show icon:</source>
        <translation>Tampilkan ikon:</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="93"/>
        <source>built in</source>
        <translation>bawaan</translation>
    </message>
    <message>
        <location filename="../batterywatchersettings.cpp" line="98"/>
        <source>Level: %1%</source>
        <translation>Level: %1%</translation>
    </message>
</context>
<context>
    <name>IdlenessWatcherSettings</name>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="17"/>
        <source>Enab&amp;le Idleness Watcher</source>
        <translation>Aktifkan Pemantau Siaga</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="34"/>
        <source>When idle then:</source>
        <translation>Saat siaga maka:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="53"/>
        <location filename="../idlenesswatchersettings.ui" line="123"/>
        <source>Idle time:</source>
        <translation>Waktu siaga:</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="66"/>
        <source> minutes</source>
        <translation> menit</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="79"/>
        <source> seconds</source>
        <translation> detik</translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="94"/>
        <source>Enable Backlight Change</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="103"/>
        <source>Backlight (%):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="130"/>
        <source>Minutes:Seconds</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="150"/>
        <source>mm:ss</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="157"/>
        <source>Check backlight</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../idlenesswatchersettings.ui" line="164"/>
        <source>On battery discharging </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LidWatcherSettings</name>
    <message>
        <location filename="../lidwatchersettings.ui" line="23"/>
        <source>Enable &amp;Lid Watcher</source>
        <translation>Aktifkan Pemantau &amp;Lid</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="38"/>
        <source>Action when lid is closed</source>
        <translation>Tindakan saat lid ditutup</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="50"/>
        <location filename="../lidwatchersettings.ui" line="115"/>
        <source>On Battery</source>
        <translation>Pada Baterai</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="58"/>
        <source>Nothing</source>
        <translation>Tidak ada</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="63"/>
        <source>Suspend</source>
        <translation>Suspensi</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="68"/>
        <source>Hibernate</source>
        <translation>Hibernasi</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="73"/>
        <source>Shut down</source>
        <translation>Matikan</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="81"/>
        <location filename="../lidwatchersettings.ui" line="125"/>
        <source>On AC</source>
        <translation>Pada AC</translation>
    </message>
    <message>
        <location filename="../lidwatchersettings.ui" line="94"/>
        <source>When &amp;using external monitor</source>
        <translation>Ketika mengunakan monitor eksternal</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="37"/>
        <source>Power Management Settings</source>
        <translation>Pengaturan Manajemen Daya</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="40"/>
        <source>Battery</source>
        <translation>Baterai</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="44"/>
        <source>Lid</source>
        <translation>Lid</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="48"/>
        <source>Idle</source>
        <translation>Siaga</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="52"/>
        <source>Power keys</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PowerKeysSettings</name>
    <message>
        <location filename="../powerkeyssettings.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="20"/>
        <source>Handle Power Keys</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="26"/>
        <source>Power Key Action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="42"/>
        <source>Suspend Key Action</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../powerkeyssettings.ui" line="49"/>
        <source>Hibernate Key Action</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../helpers.cpp" line="35"/>
        <source>Nothing</source>
        <translation>Tidak ada</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="36"/>
        <source>Ask</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="37"/>
        <source>Lock screen</source>
        <translation>Kunci layar</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="38"/>
        <source>Suspend</source>
        <translation>Suspensi</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="39"/>
        <source>Hibernate</source>
        <translation>Hibernasi</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="40"/>
        <source>Shutdown</source>
        <translation>Matikan</translation>
    </message>
    <message>
        <location filename="../helpers.cpp" line="41"/>
        <source>Turn Off monitor(s)</source>
        <translation>Matikan monitor</translation>
    </message>
</context>
</TS>
